Helper trait used by WithArgs (use it instead).
This trait is required to allow FnPtr to be a subtrait of WithArgs, which eliminates
the need for a type bound when using a fixed args type.
Using WithArgs directly would result in a cyclic supertrait error.