pub trait WithOutputImpl<F: FnPtr = Self> {
type F<T>: FnPtr<Args = F::Args, Output = T, Safety = F::Safety, Abi = F::Abi>;
}Expand description
Helper trait used by WithOutput (use it instead).
This trait is required to allow FnPtr to be a subtrait of WithOutput, which eliminates
the need for a type bound when using a fixed output type.
Using WithOutput directly would result in a cyclic supertrait error.
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".