WithSafetyImpl

Trait WithSafetyImpl 

pub trait WithSafetyImpl<Safety: Safety, F: FnPtr = Self> {
    type F: FnPtr<Args = F::Args, Output = F::Output, Safety = Safety, Abi = F::Abi>;
}
Helper trait used by WithSafety (use it instead). This trait is required to allow FnPtr to be a subtrait of WithSafety, which eliminates the need for a type bound when using a fixed safety marker. Using WithSafety directly would result in a cyclic supertrait error.

Required Associated Types

type F: FnPtr<Args = F::Args, Output = F::Output, Safety = Safety, Abi = F::Abi>

The function pointer type with the requested safety (preserving all other properties).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Safe> for extern "C" fn(A, B, C, D, E, F) -> Output

Source

type F = extern "C" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Safe> for extern "C-unwind" fn(A, B, C, D, E, F) -> Output

Source

type F = extern "C-unwind" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Safe> for extern "efiapi" fn(A, B, C, D, E, F) -> Output

Source

type F = extern "efiapi" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Safe> for extern "system" fn(A, B, C, D, E, F) -> Output

Source

type F = extern "system" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Safe> for extern "system-unwind" fn(A, B, C, D, E, F) -> Output

Source

type F = extern "system-unwind" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Safe> for extern "sysv64" fn(A, B, C, D, E, F) -> Output

Source

type F = extern "sysv64" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Safe> for extern "sysv64-unwind" fn(A, B, C, D, E, F) -> Output

Source

type F = extern "sysv64-unwind" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Safe> for fn(A, B, C, D, E, F) -> Output

Source

type F = fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Safe> for unsafe extern "C" fn(A, B, C, D, E, F) -> Output

Source

type F = extern "C" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Safe> for unsafe extern "C-unwind" fn(A, B, C, D, E, F) -> Output

Source

type F = extern "C-unwind" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Safe> for unsafe extern "efiapi" fn(A, B, C, D, E, F) -> Output

Source

type F = extern "efiapi" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Safe> for unsafe extern "system" fn(A, B, C, D, E, F) -> Output

Source

type F = extern "system" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Safe> for unsafe extern "system-unwind" fn(A, B, C, D, E, F) -> Output

Source

type F = extern "system-unwind" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Safe> for unsafe extern "sysv64" fn(A, B, C, D, E, F) -> Output

Source

type F = extern "sysv64" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Safe> for unsafe extern "sysv64-unwind" fn(A, B, C, D, E, F) -> Output

Source

type F = extern "sysv64-unwind" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Safe> for unsafe fn(A, B, C, D, E, F) -> Output

Source

type F = fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Unsafe> for extern "C" fn(A, B, C, D, E, F) -> Output

Source

type F = unsafe extern "C" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Unsafe> for extern "C-unwind" fn(A, B, C, D, E, F) -> Output

Source

type F = unsafe extern "C-unwind" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Unsafe> for extern "efiapi" fn(A, B, C, D, E, F) -> Output

Source

type F = unsafe extern "efiapi" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Unsafe> for extern "system" fn(A, B, C, D, E, F) -> Output

Source

type F = unsafe extern "system" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Unsafe> for extern "system-unwind" fn(A, B, C, D, E, F) -> Output

Source

type F = unsafe extern "system-unwind" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Unsafe> for extern "sysv64" fn(A, B, C, D, E, F) -> Output

Source

type F = unsafe extern "sysv64" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Unsafe> for extern "sysv64-unwind" fn(A, B, C, D, E, F) -> Output

Source

type F = unsafe extern "sysv64-unwind" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Unsafe> for fn(A, B, C, D, E, F) -> Output

Source

type F = unsafe fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Unsafe> for unsafe extern "C" fn(A, B, C, D, E, F) -> Output

Source

type F = unsafe extern "C" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Unsafe> for unsafe extern "C-unwind" fn(A, B, C, D, E, F) -> Output

Source

type F = unsafe extern "C-unwind" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Unsafe> for unsafe extern "efiapi" fn(A, B, C, D, E, F) -> Output

Source

type F = unsafe extern "efiapi" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Unsafe> for unsafe extern "system" fn(A, B, C, D, E, F) -> Output

Source

type F = unsafe extern "system" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Unsafe> for unsafe extern "system-unwind" fn(A, B, C, D, E, F) -> Output

Source

type F = unsafe extern "system-unwind" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Unsafe> for unsafe extern "sysv64" fn(A, B, C, D, E, F) -> Output

Source

type F = unsafe extern "sysv64" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Unsafe> for unsafe extern "sysv64-unwind" fn(A, B, C, D, E, F) -> Output

Source

type F = unsafe extern "sysv64-unwind" fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E, F> WithSafetyImpl<Unsafe> for unsafe fn(A, B, C, D, E, F) -> Output

Source

type F = unsafe fn(A, B, C, D, E, F) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Safe> for extern "C" fn(A, B, C, D, E) -> Output

Source

type F = extern "C" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Safe> for extern "C-unwind" fn(A, B, C, D, E) -> Output

Source

type F = extern "C-unwind" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Safe> for extern "efiapi" fn(A, B, C, D, E) -> Output

Source

type F = extern "efiapi" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Safe> for extern "system" fn(A, B, C, D, E) -> Output

Source

type F = extern "system" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Safe> for extern "system-unwind" fn(A, B, C, D, E) -> Output

Source

type F = extern "system-unwind" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Safe> for extern "sysv64" fn(A, B, C, D, E) -> Output

Source

type F = extern "sysv64" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Safe> for extern "sysv64-unwind" fn(A, B, C, D, E) -> Output

Source

type F = extern "sysv64-unwind" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Safe> for fn(A, B, C, D, E) -> Output

Source

type F = fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Safe> for unsafe extern "C" fn(A, B, C, D, E) -> Output

Source

type F = extern "C" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Safe> for unsafe extern "C-unwind" fn(A, B, C, D, E) -> Output

Source

type F = extern "C-unwind" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Safe> for unsafe extern "efiapi" fn(A, B, C, D, E) -> Output

Source

type F = extern "efiapi" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Safe> for unsafe extern "system" fn(A, B, C, D, E) -> Output

Source

type F = extern "system" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Safe> for unsafe extern "system-unwind" fn(A, B, C, D, E) -> Output

Source

type F = extern "system-unwind" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Safe> for unsafe extern "sysv64" fn(A, B, C, D, E) -> Output

Source

type F = extern "sysv64" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Safe> for unsafe extern "sysv64-unwind" fn(A, B, C, D, E) -> Output

Source

type F = extern "sysv64-unwind" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Safe> for unsafe fn(A, B, C, D, E) -> Output

Source

type F = fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Unsafe> for extern "C" fn(A, B, C, D, E) -> Output

Source

type F = unsafe extern "C" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Unsafe> for extern "C-unwind" fn(A, B, C, D, E) -> Output

Source

type F = unsafe extern "C-unwind" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Unsafe> for extern "efiapi" fn(A, B, C, D, E) -> Output

Source

type F = unsafe extern "efiapi" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Unsafe> for extern "system" fn(A, B, C, D, E) -> Output

Source

type F = unsafe extern "system" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Unsafe> for extern "system-unwind" fn(A, B, C, D, E) -> Output

Source

type F = unsafe extern "system-unwind" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Unsafe> for extern "sysv64" fn(A, B, C, D, E) -> Output

Source

type F = unsafe extern "sysv64" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Unsafe> for extern "sysv64-unwind" fn(A, B, C, D, E) -> Output

Source

type F = unsafe extern "sysv64-unwind" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Unsafe> for fn(A, B, C, D, E) -> Output

Source

type F = unsafe fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Unsafe> for unsafe extern "C" fn(A, B, C, D, E) -> Output

Source

type F = unsafe extern "C" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Unsafe> for unsafe extern "C-unwind" fn(A, B, C, D, E) -> Output

Source

type F = unsafe extern "C-unwind" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Unsafe> for unsafe extern "efiapi" fn(A, B, C, D, E) -> Output

Source

type F = unsafe extern "efiapi" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Unsafe> for unsafe extern "system" fn(A, B, C, D, E) -> Output

Source

type F = unsafe extern "system" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Unsafe> for unsafe extern "system-unwind" fn(A, B, C, D, E) -> Output

Source

type F = unsafe extern "system-unwind" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Unsafe> for unsafe extern "sysv64" fn(A, B, C, D, E) -> Output

Source

type F = unsafe extern "sysv64" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Unsafe> for unsafe extern "sysv64-unwind" fn(A, B, C, D, E) -> Output

Source

type F = unsafe extern "sysv64-unwind" fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D, E> WithSafetyImpl<Unsafe> for unsafe fn(A, B, C, D, E) -> Output

Source

type F = unsafe fn(A, B, C, D, E) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Safe> for extern "C" fn(A, B, C, D) -> Output

Source

type F = extern "C" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Safe> for extern "C-unwind" fn(A, B, C, D) -> Output

Source

type F = extern "C-unwind" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Safe> for extern "efiapi" fn(A, B, C, D) -> Output

Source

type F = extern "efiapi" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Safe> for extern "system" fn(A, B, C, D) -> Output

Source

type F = extern "system" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Safe> for extern "system-unwind" fn(A, B, C, D) -> Output

Source

type F = extern "system-unwind" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Safe> for extern "sysv64" fn(A, B, C, D) -> Output

Source

type F = extern "sysv64" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Safe> for extern "sysv64-unwind" fn(A, B, C, D) -> Output

Source

type F = extern "sysv64-unwind" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Safe> for fn(A, B, C, D) -> Output

Source

type F = fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Safe> for unsafe extern "C" fn(A, B, C, D) -> Output

Source

type F = extern "C" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Safe> for unsafe extern "C-unwind" fn(A, B, C, D) -> Output

Source

type F = extern "C-unwind" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Safe> for unsafe extern "efiapi" fn(A, B, C, D) -> Output

Source

type F = extern "efiapi" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Safe> for unsafe extern "system" fn(A, B, C, D) -> Output

Source

type F = extern "system" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Safe> for unsafe extern "system-unwind" fn(A, B, C, D) -> Output

Source

type F = extern "system-unwind" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Safe> for unsafe extern "sysv64" fn(A, B, C, D) -> Output

Source

type F = extern "sysv64" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Safe> for unsafe extern "sysv64-unwind" fn(A, B, C, D) -> Output

Source

type F = extern "sysv64-unwind" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Safe> for unsafe fn(A, B, C, D) -> Output

Source

type F = fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Unsafe> for extern "C" fn(A, B, C, D) -> Output

Source

type F = unsafe extern "C" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Unsafe> for extern "C-unwind" fn(A, B, C, D) -> Output

Source

type F = unsafe extern "C-unwind" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Unsafe> for extern "efiapi" fn(A, B, C, D) -> Output

Source

type F = unsafe extern "efiapi" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Unsafe> for extern "system" fn(A, B, C, D) -> Output

Source

type F = unsafe extern "system" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Unsafe> for extern "system-unwind" fn(A, B, C, D) -> Output

Source

type F = unsafe extern "system-unwind" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Unsafe> for extern "sysv64" fn(A, B, C, D) -> Output

Source

type F = unsafe extern "sysv64" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Unsafe> for extern "sysv64-unwind" fn(A, B, C, D) -> Output

Source

type F = unsafe extern "sysv64-unwind" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Unsafe> for fn(A, B, C, D) -> Output

Source

type F = unsafe fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Unsafe> for unsafe extern "C" fn(A, B, C, D) -> Output

Source

type F = unsafe extern "C" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Unsafe> for unsafe extern "C-unwind" fn(A, B, C, D) -> Output

Source

type F = unsafe extern "C-unwind" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Unsafe> for unsafe extern "efiapi" fn(A, B, C, D) -> Output

Source

type F = unsafe extern "efiapi" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Unsafe> for unsafe extern "system" fn(A, B, C, D) -> Output

Source

type F = unsafe extern "system" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Unsafe> for unsafe extern "system-unwind" fn(A, B, C, D) -> Output

Source

type F = unsafe extern "system-unwind" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Unsafe> for unsafe extern "sysv64" fn(A, B, C, D) -> Output

Source

type F = unsafe extern "sysv64" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Unsafe> for unsafe extern "sysv64-unwind" fn(A, B, C, D) -> Output

Source

type F = unsafe extern "sysv64-unwind" fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C, D> WithSafetyImpl<Unsafe> for unsafe fn(A, B, C, D) -> Output

Source

type F = unsafe fn(A, B, C, D) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Safe> for extern "C" fn(A, B, C) -> Output

Source

type F = extern "C" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Safe> for extern "C-unwind" fn(A, B, C) -> Output

Source

type F = extern "C-unwind" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Safe> for extern "efiapi" fn(A, B, C) -> Output

Source

type F = extern "efiapi" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Safe> for extern "system" fn(A, B, C) -> Output

Source

type F = extern "system" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Safe> for extern "system-unwind" fn(A, B, C) -> Output

Source

type F = extern "system-unwind" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Safe> for extern "sysv64" fn(A, B, C) -> Output

Source

type F = extern "sysv64" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Safe> for extern "sysv64-unwind" fn(A, B, C) -> Output

Source

type F = extern "sysv64-unwind" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Safe> for fn(A, B, C) -> Output

Source

type F = fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Safe> for unsafe extern "C" fn(A, B, C) -> Output

Source

type F = extern "C" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Safe> for unsafe extern "C-unwind" fn(A, B, C) -> Output

Source

type F = extern "C-unwind" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Safe> for unsafe extern "efiapi" fn(A, B, C) -> Output

Source

type F = extern "efiapi" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Safe> for unsafe extern "system" fn(A, B, C) -> Output

Source

type F = extern "system" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Safe> for unsafe extern "system-unwind" fn(A, B, C) -> Output

Source

type F = extern "system-unwind" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Safe> for unsafe extern "sysv64" fn(A, B, C) -> Output

Source

type F = extern "sysv64" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Safe> for unsafe extern "sysv64-unwind" fn(A, B, C) -> Output

Source

type F = extern "sysv64-unwind" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Safe> for unsafe fn(A, B, C) -> Output

Source

type F = fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Unsafe> for extern "C" fn(A, B, C) -> Output

Source

type F = unsafe extern "C" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Unsafe> for extern "C-unwind" fn(A, B, C) -> Output

Source

type F = unsafe extern "C-unwind" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Unsafe> for extern "efiapi" fn(A, B, C) -> Output

Source

type F = unsafe extern "efiapi" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Unsafe> for extern "system" fn(A, B, C) -> Output

Source

type F = unsafe extern "system" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Unsafe> for extern "system-unwind" fn(A, B, C) -> Output

Source

type F = unsafe extern "system-unwind" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Unsafe> for extern "sysv64" fn(A, B, C) -> Output

Source

type F = unsafe extern "sysv64" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Unsafe> for extern "sysv64-unwind" fn(A, B, C) -> Output

Source

type F = unsafe extern "sysv64-unwind" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Unsafe> for fn(A, B, C) -> Output

Source

type F = unsafe fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Unsafe> for unsafe extern "C" fn(A, B, C) -> Output

Source

type F = unsafe extern "C" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Unsafe> for unsafe extern "C-unwind" fn(A, B, C) -> Output

Source

type F = unsafe extern "C-unwind" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Unsafe> for unsafe extern "efiapi" fn(A, B, C) -> Output

Source

type F = unsafe extern "efiapi" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Unsafe> for unsafe extern "system" fn(A, B, C) -> Output

Source

type F = unsafe extern "system" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Unsafe> for unsafe extern "system-unwind" fn(A, B, C) -> Output

Source

type F = unsafe extern "system-unwind" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Unsafe> for unsafe extern "sysv64" fn(A, B, C) -> Output

Source

type F = unsafe extern "sysv64" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Unsafe> for unsafe extern "sysv64-unwind" fn(A, B, C) -> Output

Source

type F = unsafe extern "sysv64-unwind" fn(A, B, C) -> Output

Source

impl<Output, A, B, C> WithSafetyImpl<Unsafe> for unsafe fn(A, B, C) -> Output

Source

type F = unsafe fn(A, B, C) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Safe> for extern "C" fn(A, B) -> Output

Source

type F = extern "C" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Safe> for extern "C-unwind" fn(A, B) -> Output

Source

type F = extern "C-unwind" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Safe> for extern "efiapi" fn(A, B) -> Output

Source

type F = extern "efiapi" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Safe> for extern "system" fn(A, B) -> Output

Source

type F = extern "system" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Safe> for extern "system-unwind" fn(A, B) -> Output

Source

type F = extern "system-unwind" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Safe> for extern "sysv64" fn(A, B) -> Output

Source

type F = extern "sysv64" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Safe> for extern "sysv64-unwind" fn(A, B) -> Output

Source

type F = extern "sysv64-unwind" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Safe> for fn(A, B) -> Output

Source

type F = fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Safe> for unsafe extern "C" fn(A, B) -> Output

Source

type F = extern "C" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Safe> for unsafe extern "C-unwind" fn(A, B) -> Output

Source

type F = extern "C-unwind" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Safe> for unsafe extern "efiapi" fn(A, B) -> Output

Source

type F = extern "efiapi" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Safe> for unsafe extern "system" fn(A, B) -> Output

Source

type F = extern "system" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Safe> for unsafe extern "system-unwind" fn(A, B) -> Output

Source

type F = extern "system-unwind" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Safe> for unsafe extern "sysv64" fn(A, B) -> Output

Source

type F = extern "sysv64" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Safe> for unsafe extern "sysv64-unwind" fn(A, B) -> Output

Source

type F = extern "sysv64-unwind" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Safe> for unsafe fn(A, B) -> Output

Source

type F = fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Unsafe> for extern "C" fn(A, B) -> Output

Source

type F = unsafe extern "C" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Unsafe> for extern "C-unwind" fn(A, B) -> Output

Source

type F = unsafe extern "C-unwind" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Unsafe> for extern "efiapi" fn(A, B) -> Output

Source

type F = unsafe extern "efiapi" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Unsafe> for extern "system" fn(A, B) -> Output

Source

type F = unsafe extern "system" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Unsafe> for extern "system-unwind" fn(A, B) -> Output

Source

type F = unsafe extern "system-unwind" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Unsafe> for extern "sysv64" fn(A, B) -> Output

Source

type F = unsafe extern "sysv64" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Unsafe> for extern "sysv64-unwind" fn(A, B) -> Output

Source

type F = unsafe extern "sysv64-unwind" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Unsafe> for fn(A, B) -> Output

Source

type F = unsafe fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Unsafe> for unsafe extern "C" fn(A, B) -> Output

Source

type F = unsafe extern "C" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Unsafe> for unsafe extern "C-unwind" fn(A, B) -> Output

Source

type F = unsafe extern "C-unwind" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Unsafe> for unsafe extern "efiapi" fn(A, B) -> Output

Source

type F = unsafe extern "efiapi" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Unsafe> for unsafe extern "system" fn(A, B) -> Output

Source

type F = unsafe extern "system" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Unsafe> for unsafe extern "system-unwind" fn(A, B) -> Output

Source

type F = unsafe extern "system-unwind" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Unsafe> for unsafe extern "sysv64" fn(A, B) -> Output

Source

type F = unsafe extern "sysv64" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Unsafe> for unsafe extern "sysv64-unwind" fn(A, B) -> Output

Source

type F = unsafe extern "sysv64-unwind" fn(A, B) -> Output

Source

impl<Output, A, B> WithSafetyImpl<Unsafe> for unsafe fn(A, B) -> Output

Source

type F = unsafe fn(A, B) -> Output

Source

impl<Output, A> WithSafetyImpl<Safe> for extern "C" fn(A) -> Output

Source

type F = extern "C" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Safe> for extern "C-unwind" fn(A) -> Output

Source

type F = extern "C-unwind" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Safe> for extern "efiapi" fn(A) -> Output

Source

type F = extern "efiapi" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Safe> for extern "system" fn(A) -> Output

Source

type F = extern "system" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Safe> for extern "system-unwind" fn(A) -> Output

Source

type F = extern "system-unwind" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Safe> for extern "sysv64" fn(A) -> Output

Source

type F = extern "sysv64" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Safe> for extern "sysv64-unwind" fn(A) -> Output

Source

type F = extern "sysv64-unwind" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Safe> for fn(A) -> Output

Source

type F = fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Safe> for unsafe extern "C" fn(A) -> Output

Source

type F = extern "C" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Safe> for unsafe extern "C-unwind" fn(A) -> Output

Source

type F = extern "C-unwind" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Safe> for unsafe extern "efiapi" fn(A) -> Output

Source

type F = extern "efiapi" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Safe> for unsafe extern "system" fn(A) -> Output

Source

type F = extern "system" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Safe> for unsafe extern "system-unwind" fn(A) -> Output

Source

type F = extern "system-unwind" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Safe> for unsafe extern "sysv64" fn(A) -> Output

Source

type F = extern "sysv64" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Safe> for unsafe extern "sysv64-unwind" fn(A) -> Output

Source

type F = extern "sysv64-unwind" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Safe> for unsafe fn(A) -> Output

Source

type F = fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Unsafe> for extern "C" fn(A) -> Output

Source

type F = unsafe extern "C" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Unsafe> for extern "C-unwind" fn(A) -> Output

Source

type F = unsafe extern "C-unwind" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Unsafe> for extern "efiapi" fn(A) -> Output

Source

type F = unsafe extern "efiapi" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Unsafe> for extern "system" fn(A) -> Output

Source

type F = unsafe extern "system" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Unsafe> for extern "system-unwind" fn(A) -> Output

Source

type F = unsafe extern "system-unwind" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Unsafe> for extern "sysv64" fn(A) -> Output

Source

type F = unsafe extern "sysv64" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Unsafe> for extern "sysv64-unwind" fn(A) -> Output

Source

type F = unsafe extern "sysv64-unwind" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Unsafe> for fn(A) -> Output

Source

type F = unsafe fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Unsafe> for unsafe extern "C" fn(A) -> Output

Source

type F = unsafe extern "C" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Unsafe> for unsafe extern "C-unwind" fn(A) -> Output

Source

type F = unsafe extern "C-unwind" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Unsafe> for unsafe extern "efiapi" fn(A) -> Output

Source

type F = unsafe extern "efiapi" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Unsafe> for unsafe extern "system" fn(A) -> Output

Source

type F = unsafe extern "system" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Unsafe> for unsafe extern "system-unwind" fn(A) -> Output

Source

type F = unsafe extern "system-unwind" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Unsafe> for unsafe extern "sysv64" fn(A) -> Output

Source

type F = unsafe extern "sysv64" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Unsafe> for unsafe extern "sysv64-unwind" fn(A) -> Output

Source

type F = unsafe extern "sysv64-unwind" fn(A) -> Output

Source

impl<Output, A> WithSafetyImpl<Unsafe> for unsafe fn(A) -> Output

Source

type F = unsafe fn(A) -> Output

Source

impl<Output> WithSafetyImpl<Safe> for extern "C" fn() -> Output

Source

type F = extern "C" fn() -> Output

Source

impl<Output> WithSafetyImpl<Safe> for extern "C-unwind" fn() -> Output

Source

type F = extern "C-unwind" fn() -> Output

Source

impl<Output> WithSafetyImpl<Safe> for extern "efiapi" fn() -> Output

Source

type F = extern "efiapi" fn() -> Output

Source

impl<Output> WithSafetyImpl<Safe> for extern "system" fn() -> Output

Source

type F = extern "system" fn() -> Output

Source

impl<Output> WithSafetyImpl<Safe> for extern "system-unwind" fn() -> Output

Source

type F = extern "system-unwind" fn() -> Output

Source

impl<Output> WithSafetyImpl<Safe> for extern "sysv64" fn() -> Output

Source

type F = extern "sysv64" fn() -> Output

Source

impl<Output> WithSafetyImpl<Safe> for extern "sysv64-unwind" fn() -> Output

Source

type F = extern "sysv64-unwind" fn() -> Output

Source

impl<Output> WithSafetyImpl<Safe> for fn() -> Output

Source

type F = fn() -> Output

Source

impl<Output> WithSafetyImpl<Safe> for unsafe extern "C" fn() -> Output

Source

type F = extern "C" fn() -> Output

Source

impl<Output> WithSafetyImpl<Safe> for unsafe extern "C-unwind" fn() -> Output

Source

type F = extern "C-unwind" fn() -> Output

Source

impl<Output> WithSafetyImpl<Safe> for unsafe extern "efiapi" fn() -> Output

Source

type F = extern "efiapi" fn() -> Output

Source

impl<Output> WithSafetyImpl<Safe> for unsafe extern "system" fn() -> Output

Source

type F = extern "system" fn() -> Output

Source

impl<Output> WithSafetyImpl<Safe> for unsafe extern "system-unwind" fn() -> Output

Source

type F = extern "system-unwind" fn() -> Output

Source

impl<Output> WithSafetyImpl<Safe> for unsafe extern "sysv64" fn() -> Output

Source

type F = extern "sysv64" fn() -> Output

Source

impl<Output> WithSafetyImpl<Safe> for unsafe extern "sysv64-unwind" fn() -> Output

Source

type F = extern "sysv64-unwind" fn() -> Output

Source

impl<Output> WithSafetyImpl<Safe> for unsafe fn() -> Output

Source

type F = fn() -> Output

Source

impl<Output> WithSafetyImpl<Unsafe> for extern "C" fn() -> Output

Source

type F = unsafe extern "C" fn() -> Output

Source

impl<Output> WithSafetyImpl<Unsafe> for extern "C-unwind" fn() -> Output

Source

type F = unsafe extern "C-unwind" fn() -> Output

Source

impl<Output> WithSafetyImpl<Unsafe> for extern "efiapi" fn() -> Output

Source

type F = unsafe extern "efiapi" fn() -> Output

Source

impl<Output> WithSafetyImpl<Unsafe> for extern "system" fn() -> Output

Source

type F = unsafe extern "system" fn() -> Output

Source

impl<Output> WithSafetyImpl<Unsafe> for extern "system-unwind" fn() -> Output

Source

type F = unsafe extern "system-unwind" fn() -> Output

Source

impl<Output> WithSafetyImpl<Unsafe> for extern "sysv64" fn() -> Output

Source

type F = unsafe extern "sysv64" fn() -> Output

Source

impl<Output> WithSafetyImpl<Unsafe> for extern "sysv64-unwind" fn() -> Output

Source

type F = unsafe extern "sysv64-unwind" fn() -> Output

Source

impl<Output> WithSafetyImpl<Unsafe> for fn() -> Output

Source

type F = unsafe fn() -> Output

Source

impl<Output> WithSafetyImpl<Unsafe> for unsafe extern "C" fn() -> Output

Source

type F = unsafe extern "C" fn() -> Output

Source

impl<Output> WithSafetyImpl<Unsafe> for unsafe extern "C-unwind" fn() -> Output

Source

type F = unsafe extern "C-unwind" fn() -> Output

Source

impl<Output> WithSafetyImpl<Unsafe> for unsafe extern "efiapi" fn() -> Output

Source

type F = unsafe extern "efiapi" fn() -> Output

Source

impl<Output> WithSafetyImpl<Unsafe> for unsafe extern "system" fn() -> Output

Source

type F = unsafe extern "system" fn() -> Output

Source

impl<Output> WithSafetyImpl<Unsafe> for unsafe extern "system-unwind" fn() -> Output

Source

type F = unsafe extern "system-unwind" fn() -> Output

Source

impl<Output> WithSafetyImpl<Unsafe> for unsafe extern "sysv64" fn() -> Output

Source

type F = unsafe extern "sysv64" fn() -> Output

Source

impl<Output> WithSafetyImpl<Unsafe> for unsafe extern "sysv64-unwind" fn() -> Output

Source

type F = unsafe extern "sysv64-unwind" fn() -> Output

Source

impl<Output> WithSafetyImpl<Unsafe> for unsafe fn() -> Output

Source

type F = unsafe fn() -> Output

Implementors